pub struct SequenceOptions {
pub data_type: String,
pub min_value: Option<i64>,
pub max_value: Option<i64>,
pub cycle: bool,
pub cache_size: i64,
}Expand description
Durable SQL sequence state. Sequence allocation is implemented by the catalog backend as one atomic mutation so independent engine sessions (and independently opened engines) cannot return the same value.
Fields
data_type: Stringmin_value: Option<i64>None is accepted only while decoding a legacy row and is resolved from its increment direction by native sequence restoration.
max_value: Option<i64>None is accepted only while decoding a legacy row and is resolved from its increment direction by native sequence restoration.
cycle: boolcache_size: i64Trait Implementations
Sourceimpl Clone for SequenceOptions
impl Clone for SequenceOptions
Sourcefn clone(&self) -> SequenceOptions
fn clone(&self) -> SequenceOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SequenceOptions
impl Debug for SequenceOptions
Sourceimpl Default for SequenceOptions
impl Default for SequenceOptions
Sourceimpl<'de> Deserialize<'de> for SequenceOptions
impl<'de> Deserialize<'de> for SequenceOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SequenceOptions
Sourceimpl PartialEq for SequenceOptions
impl PartialEq for SequenceOptions
Sourceimpl Serialize for SequenceOptions
impl Serialize for SequenceOptions
impl StructuralPartialEq for SequenceOptions